using System;
using System.Collections.Generic;
using System.Text;
using VSSDKAssist.Assets.ValueProviders.Base;
using VSSDKAssist.Assets.Helpers;
using EnvDTE;

namespace VSSDKAssist.Recipes.Common.ValueProviders
{
	/// <summary>
	/// Value provider for the Resources folder ProjectItem
	/// </summary>
	public class ResourcesFolderValueProvider : ValueProviderBase
	{
		/// <summary>
		/// Contains code that will be called when recipe execution begins. This is the first method in the lifecycle.
		/// </summary>
		/// <param name="currentValue">An <see cref="T:System.Object"/> that contains the current value of the argument.</param>
		/// <param name="newValue">When this method returns, contains an <see cref="T:System.Object"/> that contains
		/// the new value of the argument, if the returned value
		/// of the method is <see langword="true"/>. Otherwise, it is ignored.</param>
		/// <returns>
		/// 	<see langword="true"/> if the argument value should be replaced with
		/// the value in <paramref name="newValue"/>; otherwise, <see langword="false"/>.
		/// </returns>
		/// <remarks>By default, always returns <see langword="false"/>, unless overriden by a derived class.</remarks>
		public override bool OnBeginRecipe(object currentValue, out object newValue)
		{
			newValue = null;

			if((currentValue == null) && (this.ExecutionStage != Stage.OnBeforeActions))
			{
				if(VisualStudio.SelectedItems.Count == 1)
				{
					Project project = VisualStudio.SelectedItems.Item(1).Project as Project;

					if(project != null)
					{
						ProjectItem folder = VSIPHelper.FindItemByName(project.ProjectItems, "Resources", true);

						if(folder != null)
						{
							newValue = folder;
							return true;
						}
					}
				}
			}

			return false;
		}
	}
}