using System.Collections.Specialized;
using System.ComponentModel;
using EnvDTE;
using Microsoft.Practices.RecipeFramework.Library.Converters;
using Microsoft.Practices.RecipeFramework.Library.Editors;
using Microsoft.Practices.WizardFramework;
using Microsoft.VisualStudio.Shell;
using VSSDKAssist.Recipes.Common.CustomPages;

namespace VSSDKAssist.Recipes.CreateSetupProject
{
	/// <summary>
    /// Custom page for CreateSetupProjectCP recipe
	/// </summary>
	public partial class CreateSetupProjectCP : WizardPageBase
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="CreateSetupProjectCP"/> class.
		/// </summary>
        public CreateSetupProjectCP()
		{
		}

		/// <summary>
		/// Initializes a new instance of the <see cref="CreateSetupProjectCP"/> class.
		/// </summary>
		/// <param name="wizard">The <see cref="T:Microsoft.Practices.WizardFramework.WizardForm"/>that will host the new page.</param>
		public CreateSetupProjectCP(WizardForm wizard)
			: base(wizard)
		{
			InitializeComponent();
		}

        [RecipeArgument]
        public Project VSPackageProject
        {
            get { return (Project)vePackageProject.Value; }
            set
            {
                if(value != null)
                {
                    vePackageProject.TextBox.Text = new ProjectConverter().ConvertTo(value, typeof(string)) as string;
                }
            }
        }

        [RecipeArgument]
        public string Manufacturer
        {
            get { return veManufacturer.Value.ToString(); }
            set
            {
                if(value != null)
                {
                    veManufacturer.TextBox.Text = value;
                }
            }
        }

        [RecipeArgument]
        public string ProductNameArgument
        {
            get { return veProductName.Value.ToString(); }
            set
            {
                if(value != null)
                {
                    veProductName.TextBox.Text = value;
                }
            }
        }

        [RecipeArgument]
        public string Description
        {
            get { return veDescription.Value.ToString(); }
            set
            {
                if(value != null)
                {
                    veDescription.TextBox.Text = value;
                }
            }
        }

        [RecipeArgument]
        public string Comments
        {
            get { return veComments.Value.ToString(); }
            set
            {
                if(value != null)
                {
                    veComments.TextBox.Text = value;
                }
            }
        }

		/// <summary>
		/// Gets or sets the registration method.
		/// </summary>
		/// <value>The registration method.</value>
		[RecipeArgument]
		public RegistrationMethod RegistrationMethod
		{
			get { return (RegistrationMethod)veRegistrationMethod.Value; }
			set
			{
				veRegistrationMethod.TextBox.Text = value.ToString();
			}
		}

		/// <summary>
		/// Gets or sets the site of the control.
		/// </summary>
		/// <value></value>
		/// <returns>The <see cref="T:System.ComponentModel.ISite"></see> associated with the <see cref="T:System.Windows.Forms.Control"></see>, if any.</returns>
		/// <PermissionSet><IPermission class="System.Security.Permissions.EnvironmentPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Unrestricted="true"/><IPermission class="System.Security.Permissions.FileIOPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Unrestricted="true"/><IPermission class="System.Security.Permissions.SecurityPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Flags="UnmanagedCode, ControlEvidence"/><IPermission class="System.Diagnostics.PerformanceCounterPermission, System, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Unrestricted="true"/></PermissionSet>
		public override ISite Site
		{
			get
			{
				return base.Site;
			}
			set
			{
				base.Site = value;
				if(value != null)
				{
                    this.vePackageProject.BeginInit();
                    this.vePackageProject.ValueType = typeof(Project);
                    base.Site.Container.Add(vePackageProject);
                    SolutionPickerEditor solutionPickerEditor1 = new SolutionPickerEditor();
                    StringDictionary solutionPickerEditorAttributes1 = new StringDictionary();
                    solutionPickerEditorAttributes1.Add("UnboundReferenceType", "VSSDKAssist.Assets.References.VisualStudio.ProjectReference, VSSDKAssist.Assets");
                    solutionPickerEditor1.Configure(solutionPickerEditorAttributes1);
                    this.vePackageProject.EditorInstance = solutionPickerEditor1;
                    this.vePackageProject.ConverterInstance = new ProjectConverter();
                    this.vePackageProject.EndInit();

					this.veRegistrationMethod.BeginInit();
					this.veRegistrationMethod.ValueType = typeof(RegistrationMethod);
					base.Site.Container.Add(veRegistrationMethod);
					this.veRegistrationMethod.ConverterInstance = new EnumConverter(typeof(RegistrationMethod));
					this.veRegistrationMethod.EndInit();

                    this.veManufacturer.BeginInit();
                    this.veManufacturer.ValueType = typeof(string);
                    base.Site.Container.Add(veManufacturer);
                    this.veManufacturer.EndInit();

                    this.veProductName.BeginInit();
                    this.veProductName.ValueType = typeof(string);
                    base.Site.Container.Add(veProductName);
                    this.veProductName.EndInit();

                    this.veDescription.BeginInit();
                    this.veDescription.ValueType = typeof(string);
                    base.Site.Container.Add(veDescription);
                    this.veDescription.EndInit();

                    this.veComments.BeginInit();
                    this.veComments.ValueType = typeof(string);
                    base.Site.Container.Add(veComments);
                    this.veComments.EndInit();
				}
			}
		}

		private void veRegistrationMethod_ValueChanged(object sender, System.ComponentModel.Design.ComponentChangedEventArgs e)
		{
			RegistrationMethod registrationMethod = (RegistrationMethod)veRegistrationMethod.Value;
			DictionaryService.SetValue("RegistrationMethod", registrationMethod);
		}

        private void vePackageProject_ValueChanged(object sender, System.ComponentModel.Design.ComponentChangedEventArgs e)
        {
            Project project = (Project)vePackageProject.Value;
            DictionaryService.SetValue("VSPackageProject", project);
        }

        private void veManufacturer_ValueChanged(object sender, System.ComponentModel.Design.ComponentChangedEventArgs e)
        {
            string manufacturer = veManufacturer.Value as string;
            DictionaryService.SetValue("Manufacturer", manufacturer);
        }

        private void veProductName_ValueChanged(object sender, System.ComponentModel.Design.ComponentChangedEventArgs e)
        {
            string productName = veProductName.Value as string;
            DictionaryService.SetValue("ProductNameArgument", productName);
        }

        private void veDescription_ValueChanged(object sender, System.ComponentModel.Design.ComponentChangedEventArgs e)
        {
            string description = veDescription.Value as string;
            DictionaryService.SetValue("Description", description);
        }

        private void veComments_ValueChanged(object sender, System.ComponentModel.Design.ComponentChangedEventArgs e)
        {
            string comments = veComments.Value as string;
            DictionaryService.SetValue("Comments", comments);
        }
	}
}