using System.Diagnostics;
using System.IO;
using Microsoft.Practices.RecipeFramework;
using VSSDKAssist.Assets.Actions.Base;
using VSSDKAssist.Assets.Actions.General;
using VSSDKAssist.Assets.Enums;
using VSSDKAssist.Recipes.Common.Helpers;

namespace VSSDKAssist.Recipes.TestSplashScreen
{
	/// <summary>
	/// Action thats tests a VS splash screen
	/// </summary>
	public class TestSplashScreenAction : ActionBase
	{
		private VSHive vsHive = VSHive.Experimental;

		/// <summary>
		/// Gets or sets the vs hive.
		/// </summary>
		/// <value>The vs hive.</value>
		[Input(Required = false)]
		public VSHive VSHive
		{
			get { return vsHive; }
			set { vsHive = value; }
		}

		/// <summary>
		/// Called when [execute].
		/// </summary>
		protected override void OnExecute()
		{
			using(ExecuteProcessAction executeProcessAction = new ExecuteProcessAction())
			{
				executeProcessAction.Site = this.Site;
				executeProcessAction.FileName =
					Path.Combine(CommonHelper.GetVSInstallPath(), Constants.DevEnv);

				switch(this.vsHive)
				{
					case VSHive.Standard:
						executeProcessAction.Arguments = @"/Splash";
						break;
					case VSHive.Experimental:
                        executeProcessAction.Arguments = @"/rootSuffix Exp  /RANU /Splash";
						break;
					default:
                        executeProcessAction.Arguments = @"/rootSuffix Exp  /RANU /Splash";
						break;
				}

				executeProcessAction.CreateWindow = true;
				executeProcessAction.WindowStyle = ProcessWindowStyle.Maximized;
				executeProcessAction.WaitForExit = false;
				executeProcessAction.Execute();
			}
		}
	}
}