﻿using System.IO;
using EnvDTE;
using Microsoft.Practices.RecipeFramework;
using VSSDKAssist.Assets.Actions.Base;
using VSSDKAssist.Assets.Helpers;

namespace VSSDKAssist.Assets.Actions.VisualStudio
{
	/// <summary>
	/// The action adds a file to a project
	/// The other input properties of the action are 
	/// (a) SourceFileName - provides the name of the file 
	/// (b) SourceFilePath - provides the path name of the file
	/// </summary>
	public class AddItemFromFileToProjectAction : ActionBase
	{
		#region Properties

		private string sourceFileName;

		/// <summary>
		/// Name of the source file
		/// </summary>
		[Input(Required = true)]
		public string SourceFileName
		{
			get { return sourceFileName; }
			set { sourceFileName = value; }
		}

		private string sourceFilePath = string.Empty;

		/// <summary>
		/// Name of the source file path
		/// </summary>
		[Input(Required = false)]
		public string SourceFilePath
		{
			get { return sourceFilePath; }
			set { sourceFilePath = value; }
		}

		private Project project;

		/// <summary>
		/// The Project object where to add the file
		/// </summary>
		[Input(Required = true)]
		public Project Project
		{
			get { return project; }
			set { project = value; }
		}

		private bool open = true;

		/// <summary>
		/// A flag to indicate if the newly created item should be shown
		/// in a window.
		/// </summary>
		[Input(Required = false)]
		public bool Open
		{
			get { return open; }
			set { open = value; }
		}

		private ProjectItem projectItem;

		/// <summary>
		/// A property that can be used to pass the creted item to
		/// a following action.
		/// </summary>
		[Output]
		public ProjectItem ProjectItem
		{
			get { return projectItem; }
			set { projectItem = value; }
		}
		#endregion

		/// <summary>
		/// Called when [execute].
		/// </summary>
		protected override void OnExecute()
		{
			string fileName = this.sourceFileName;

			if(!string.IsNullOrEmpty(this.sourceFilePath))
			{
				fileName = Path.Combine(this.sourceFilePath, this.sourceFileName);
			}

			projectItem = VSIPHelper.FindItemByName(this.Project.ProjectItems, Path.GetFileName(fileName), false);

			if(projectItem == null)
			{
				projectItem = this.Project.ProjectItems.AddFromFileCopy(fileName);
			}
		}

		/// <summary>
		/// Called when [undo].
		/// </summary>
		protected override void OnUndo()
		{
			if(projectItem != null)
			{
				projectItem.Delete();
			}
		}
	}
}