using System;
using System.Collections.Specialized;
using System.IO;
using EnvDTE;
using VSSDKAssist.Assets.ValueProviders.Base;

namespace VSSDKAssist.Assets.ValueProviders.VisualStudio
{
	/// <summary>
	/// Value provider for a project path
	/// </summary>
	public class ProjectPathValueProvider : ValueProviderBase
    {
		#region Constants
		private const string ProjectArgument = "ProjectArgument";
		#endregion

		#region Fields
		private string projectArgument;
		#endregion

		/// <summary>
		/// Contains code that will be called before actions are executed.
		/// </summary>
		/// <param name="currentValue">An <see cref="T:System.Object"/> that contains the current value of the argument.</param>
		/// <param name="newValue">When this method returns, contains an <see cref="T:System.Object"/> that contains
		/// the new value of the argument, if the returned value
		/// of the method is <see langword="true"/>. Otherwise, it is ignored.</param>
		/// <returns>
		/// 	<see langword="true"/> if the argument value should be replaced with
		/// the value in <paramref name="newValue"/>; otherwise, <see langword="false"/>.
		/// </returns>
		/// <remarks>By default, always returns <see langword="false"/>, unless overridden by a derived class.</remarks>
        public override bool OnBeforeActions(object currentValue, out object newValue)
        {
			newValue = null;

			if((currentValue == null) && (this.ExecutionStage != Stage.OnBeginRecipe))
			{
				Project project = DictionaryService.GetValue(projectArgument) as Project;
                
				newValue = Path.GetDirectoryName(project.Properties.Item("FullPath").Value.ToString());

				if(newValue != null)
                {
                    return true;
                }
            }

			return false;
        }

		/// <summary>
		/// Called when [configure].
		/// </summary>
		/// <param name="attributes">The attributes.</param>
        protected override void OnConfigure(StringDictionary attributes)
        {
			if(attributes == null)
				throw new ArgumentNullException("attributes");

			if(attributes.ContainsKey(ProjectArgument))
			{
				projectArgument = attributes[ProjectArgument];
			}
        }
    }
}